@@ -12,8 +12,8 @@ from mstrio.object_management import folder
 import pandas as pd
 #import error_controller
 #from mstrio.utils.error_handlers import ErrorHandler
-import helper
-import logger
+from src.mstr_robotics import helper
+from src.mstr_robotics import logger
 
 log=logger
 @log.logger(err_name=f'Failed to open the a connection to the I-Server.')
